==> mythplugins_0.20.orig.tar.gz: mythplugins-0.20/mythweb/modules/_shared/tmpl/wap/header.php <==
<?php
/**
 * WAP header
 *
 * @url         $URL: svn+ssh://ijr@cvs.mythtv.org/var/lib/svn/trunk/mythplugins/mythweb/modules/_shared/tmpl/wap/header.php $
 * @date        $Date: 2006-03-26 05:09:14 -0500 (Sun, 26 Mar 2006) $
 * @version     $Revision: 9493 $
 * @author      $Author: xris $
 * @license     GPL
 *
 * @package     MythWeb
 *
/**/

// UTF-8 content
    header("Content-Type: text/html; charset=utf-8");

?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>

<head>
    <title><?php echo htmlentities($page_title) ?></title>
    <Link Rel="stylesheet" HRef="<?php echo skin_url ?>style.css" Type="text/css" Media="screen">
    <Link Rel="stylesheet" HRef="<?php echo skin_url ?>handheld.css" Type="text/css" Media="handheld">
</head>

<body bgcolor="#003060" text="#DEDEDE" link="#3181B4" alink="#CC0000" vlink="#3181B4">

<center><img src="<?php echo skin_url ?>img/mythtv-logo.gif" border="0" alt="MythTV"><br />

    <span class="menu">
        <a href="<?php echo root ?>tv/list"><?php echo t('Listings') ?></a><br />
        <a href="<?php echo root ?>tv/upcoming"><?php echo t('Upcoming Recordings') ?></a><br />
        <a href="<?php echo root ?>tv/recorded"><?php echo t('Recorded Programs') ?></a><br />
        <a href="<?php echo root ?>status"><?php echo t('Backend Status') ?></a><br />
    </span>

</center><br />
<form action="<?php echo root ?>tv/search" method="post">
        <center><input type="text" name="searchstr" value="<?php echo $_GET['searchstr'] ?>"><br />
        <input type="submit" class="submit" value="search"></center><br />
</form>

==> mythplugins_0.20.2.orig.tar.gz: mythplugins-0.20.2/mythweb/modules/_shared/tmpl/wap/header.php <==
<?php
/**
 * WAP header
 *
 * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/_shared/tmpl/wap/header.php $
 * @date        $Date: 2006-09-30 00:46:38 -0500 (Sat, 30 Sep 2006) $
 * @version     $Revision: 11338 $
 * @author      $Author: xris $
 * @license     GPL
 *
 * @package     MythWeb
 *
/**/

// UTF-8 content
    header("Content-Type: text/html; charset=utf-8");

?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>

<head>
    <title><?php echo htmlentities($page_title) ?></title>
    <Link Rel="stylesheet" HRef="<?php echo skin_url ?>style.css" Type="text/css" Media="screen">
    <Link Rel="stylesheet" HRef="<?php echo skin_url ?>handheld.css" Type="text/css" Media="handheld">
</head>

<body bgcolor="#003060" text="#DEDEDE" link="#3181B4" alink="#CC0000" vlink="#3181B4">

<center><img src="<?php echo skin_url ?>img/mythtv-logo.gif" border="0" alt="MythTV"><br />

    <span class="menu">
        <a href="<?php echo root ?>tv/list"><?php echo t('Listings') ?></a><br />
        <a href="<?php echo root ?>tv/upcoming"><?php echo t('Upcoming Recordings') ?></a><br />
        <a href="<?php echo root ?>tv/recorded"><?php echo t('Recorded Programs') ?></a><br />
        <a href="<?php echo root ?>status"><?php echo t('Backend Status') ?></a><br />
    </span>

</center><br />
<form action="<?php echo root ?>tv/search" method="get">
        <center><input type="text" name="s" value="<?php echo $_GET['s'] ?>"><br />
        <input type="submit" class="submit" name="search" value="Search"></center><br />
</form>
